@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2006  Andreas Rver
+ * Copyright (C) 2000-2012  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
  */
 
 #include "bonus.h"
-#include "event.h"
+#include "keyb.h"
 #include "screen.h"
 #include "menu.h"
 #include "decl.h"
@@ -48,7 +48,7 @@ static Sint32 torpedox, torpedoy, subposx, subposy;
 
 /* current game time
  */
-static Sint32 currtime;
+static Sint32 time;
 
 /* current xposition, this is ongoing from tower to
  * tower so that you continue where you've left of in
@@ -62,10 +62,10 @@ static void show() {
   /* lets first calc the position of the tower on the screen */
   Sint32 towerpos;
 
-  if (currtime < gametime/2)
-    towerpos = -(4*currtime);
+  if (time < gametime/2)
+    towerpos = -(4*time);
   else
-    towerpos = gametime * scrollerspeed - 4*currtime + SCREENWID + (SPR_SLICEWID*2);
+    towerpos = gametime * scrollerspeed - 4*time + SCREENWID + (SPR_SLICEWID*2);
 
   /* draw the background layers */
   scr_draw_bonus1(xpos, towerpos);
@@ -75,7 +75,7 @@ static void show() {
     scr_draw_torpedo(torpedoy, torpedox);
 
   /* output the submarine */
-  scr_draw_submarine(subposy - 20, subposx, currtime % 9);
+  scr_draw_submarine(subposy - 20, subposx, time % 9);
 
   /* and the fishes */
   for (int b = 0; b < fishcnt; b++)
@@ -94,13 +94,13 @@ static void bonus_background_proc(void) {
 
 static bool escape(void) {
 
-  Menusystem::set_bgproc(bonus_background_proc);
+  set_men_bgproc(bonus_background_proc);
   return men_game();
 }
 
-static void dopause(void) {
+static void pause(void) {
 
-  Menusystem::set_bgproc(bonus_background_proc);
+  set_men_bgproc(bonus_background_proc);
   men_info(_("Pause"), -1, 1);
 }
 
@@ -137,7 +137,9 @@ bool bns_game(void) {
   torpedox = -1;
 
   /* restart timer */
-  currtime = 0;
+  time = 0;
+
+  key_readkey();
 
   do {
 
@@ -160,7 +162,7 @@ bool bns_game(void) {
 
     /* move submarine */
     if (!automatic) {
-      if (events.check_for(fire_ev)) {
+      if (key_keypressed(fire_key)) {
         if (torpedox == -1) {
           torpedox = subposx + TORPEDO_OFS_X;
           torpedoy = subposy + TORPEDO_OFS_Y;
@@ -168,21 +170,21 @@ bool bns_game(void) {
         }
       }
 
-      if (events.check_for(down_ev)) {
+      if ((key_keystat() & down_key) != 0) {
         if (subposy < SUBM_MAX_Y)
           subposy += 4;
       } else {
-	if (events.check_for(up_ev)) {
+        if ((key_keystat() & up_key) != 0) {
           if (subposy > SUBM_MIN_Y)
             subposy -= 4;
         }
       }
 
-      if (events.check_for(left_ev)) {
+      if ((key_keystat() & left_key) != 0) {
         if (subposx > SUBM_MIN_X)
           subposx -= 8;
       } else {
-        if (events.check_for(right_ev)) {
+        if ((key_keystat() & right_key) != 0) {
           if (subposx < SUBM_MAX_X)
             subposx += 4;
         }
@@ -198,15 +200,15 @@ bool bns_game(void) {
     }
 
     /* escape or pausekey pressed */
-    if (events.check_for(break_ev)) {
+    if (key_keypressed(break_key))
       if (escape()) {
         return false;
       }
-    }
 
-    if (events.check_for(pause_ev)) {
-      dopause();
-    }
+    if (key_keypressed(pause_key))
+      pause();
+
+    key_readkey();
 
     /* move the fish */
     for (b = 0; b < fishcnt; b++) {
@@ -252,22 +254,22 @@ bool bns_game(void) {
     }
 
     /* change towercolor in the middle of the game */
-    if ((currtime > gametime/2) && !newtowercol) {
+    if ((time > gametime/2) && !newtowercol) {
       scr_settowercolor(lev_towercol_red(), lev_towercol_green(), lev_towercol_blue());
       newtowercol = true;
     }
 
     /* end of game, switch to automatic, stop scrolling */
-    if (currtime == gametime) {
+    if (time == gametime) {
       automatic = true;
       if ((subposx == SUBM_TARGET_X) && (subposy == SUBM_TARGET_Y)) break;
     } else {
       xpos +=4;
       xpos_ofs += 4;
-      currtime++;
+      time++;
     }
 
-    if (!((currtime + 20) & 0x3f)) ttsounds::instance()->startsound(SND_SONAR);
+    if (!((time + 20) & 0x3f)) ttsounds::instance()->startsound(SND_SONAR);
 
     /* display screen and wait */
     show();
