@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2004  Andreas Rver
+ * Copyright (C) 2000-2012  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
 #include "configuration.h"
 #include <string.h>
 #include <stdlib.h>
-#include "event.h"
+#include "keyb.h"
 
 static bool
 str2bool(char *s) {
@@ -55,7 +55,7 @@ void configuration::parse(FILE * in) {
             break;
           case CT_KEY:
             if (atoi(param) > 0)
-              events.set_keydef((event_t)t->maxlen,(SDLKey)atoi(param));
+              key_redefine((ttkey)t->maxlen, (SDLKey)atoi(param));
             break;
           default: assert_msg(0, "Unknown config data type.");
           }
@@ -121,11 +121,11 @@ configuration::configuration(FILE *glob, FILE *local) {
   CNF_INT(  "editor_pagesize",     &i_editor_towerpagesize );
   CNF_INT(  "editor_towerstarthei",&i_editor_towerstarthei );
   CNF_INT(  "waves_type",          &i_waves_type );
-  CNF_KEY(  "key_fire",             fire_ev );
-  CNF_KEY(  "key_up",               up_ev );
-  CNF_KEY(  "key_down",             down_ev );
-  CNF_KEY(  "key_left",             left_ev );
-  CNF_KEY(  "key_right",            right_ev );
+  CNF_KEY(  "key_fire",             fire_key );
+  CNF_KEY(  "key_up",               up_key );
+  CNF_KEY(  "key_down",             down_key );
+  CNF_KEY(  "key_left",             left_key );
+  CNF_KEY(  "key_right",            right_key );
   CNF_CHAR( "password",            &i_curr_password, PASSWORD_LEN );
   CNF_INT(  "start_lives",         &i_start_lives );
   CNF_INT(  "game_speed",          &i_game_speed);
@@ -148,11 +148,10 @@ configuration::configuration(FILE *glob, FILE *local) {
 
 configuration::~configuration(void) {
 
-  if (need_save && !f) 
+  if (need_save && !f)
     f = create_local_config_file(".toppler.rc");
-
-  if (need_save && f) {
-
+  if (need_save && f)
+  {
     fseek(f, 0, SEEK_SET);
 
     config_data *t = first_data;
@@ -171,7 +170,7 @@ configuration::~configuration(void) {
         fprintf(f, "%i", *(int *)t->cnf_var);
         break;
       case CT_KEY:
-        fprintf(f, "%i", (int)events.get_keydef_sdl((event_t)t->maxlen));
+        fprintf(f, "%i", (int)key_conv2sdlkey((ttkey)t->maxlen, true));
         break;
       default: assert_msg(0, "Unknown config data type.");
       }
@@ -181,7 +180,7 @@ configuration::~configuration(void) {
       t = t->next;
     }
   }
-  if (f) fclose(f);
+  if (f) { fclose(f); f=NULL; }
 
   config_data *t = first_data;
 
