@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2006  Andreas Rver
+ * Copyright (C) 2000-2012  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,13 +31,6 @@
 #include <pwd.h>
 #endif
 
-static char * acat(const char *a, const char *b) {
-  size_t len = strlen(a)+strlen(b)+2;
-  char *s = (char *)malloc(len);
-  snprintf(s, len-1,"%s%s",a,b);
-  return s;
-}
-
 
 static bool wait_overflow = false;
 /* Not read from config file */
@@ -112,12 +105,21 @@ char * homedir()
 
 }
 
+static char * acat(const char *a, const char *b)
+{
+  size_t len = strlen(a)+strlen(b)+2;
+  char *s = (char*)malloc(len);
+  snprintf(s, len-1,"%s%s",a,b);
+  return s;
+}
+
+
 /* checks if home/.toppler exists and creates it, if not */
 static void checkdir(void) {
 
 #ifndef WIN32
 
-  char *n=acat(homedir(),"/.toppler");
+  char *n = acat(homedir(),"/.toppler");
 
   DIR *d = opendir(n);
 
@@ -125,8 +127,9 @@ static void checkdir(void) {
     mkdir(n, S_IRWXU);
   }
 
-  free(n);
+  closedir(d);
 
+  free(n);
 #endif
 
 }
@@ -144,9 +147,10 @@ FILE *open_data_file(const char *name) {
   char *n = acat(TOP_DATADIR"/", name);
 
   if (dcl_fileexists(n))
-    f=fopen(n, "rb");
+    f = fopen(n, "rb");
 
   free(n);
+
   return f;
 
 #else
@@ -164,21 +168,21 @@ bool get_data_file_path(const char * name, char * f, int len) {
 #ifndef WIN32
   // look into actual directory
   if (dcl_fileexists(name)) {
-    snprintf(f, len, name);
+    snprintf(f, len, "%s", name);
     return true;
   }
 
   // look into the data dir
-  char *n=acat(TOP_DATADIR"/",name);
+  char *n = acat(TOP_DATADIR"/", name);
 
   if (dcl_fileexists(n)) {
     snprintf(f, len, "%s", n);
     free(n);
     return true;
-  } else {
-    free(n);
   }
-  return(false);
+
+  free(n);
+  return false;
 
 #else
 
@@ -195,42 +199,44 @@ bool get_data_file_path(const char * name, char * f, int len) {
 static char * acat3(const char *a, const char *b, const char *c)
 {
   size_t len = strlen(a)+strlen(b)+strlen(c)+2;
-  char *s = (char *)malloc(len);
+  char *s = (char*)malloc(len);
   snprintf(s, len-1,"%s%s%s",a,b,c);
   return s;
 }
 
-
 static char * topplername(const char *name)
-{ 
+{
 #ifndef WIN32
-  return acat3(homedir(),"/.toppler/",name);
+  return acat3(homedir(),"/.toppler/", name);
 #else
   return strdup(name);
 #endif
 }
 
 FILE *open_local_config_file(const char *name) {
-  FILE *f=NULL;
-  char *n=topplername(name);
-  if(dcl_fileexists(n))
-    f=fopen(n,"r+");
+
+  FILE *f = NULL;
+  checkdir();
+
+  char *n = topplername(name);
+
+  if (dcl_fileexists(n))
+    f = fopen(n, "r+");
+
   free(n);
-  return(f);
+  return f;
 }
 
 FILE *create_local_config_file(const char *name) {
 
-
   checkdir();
 
-  char *n=topplername(name);
-  FILE *f=fopen(n,"wb+");
+  char *n = topplername(name);
+  FILE *f = fopen(n, "wb+");
   free(n);
-  return(f);
+  return f;
 }
 
-
 /* used for tower and mission saving */
 
 FILE *open_local_data_file(const char *name) {
@@ -240,17 +246,17 @@ FILE *open_local_data_file(const char *name) {
   char *n = topplername(name);
   FILE *f = fopen(n, "rb");
   free(n);
-  return(f);
+  return f;
 }
 
 FILE *create_local_data_file(const char *name) {
 
   checkdir();
 
-  char *n=topplername(name);
-  FILE *f=fopen(n,"wb+");
+  char *n = topplername(name);
+  FILE * f = fopen(n, "wb+");
   free(n);
-  return(f);
+  return f;
 }
 
 static int sort_by_name(const void *a, const void *b) {
@@ -290,7 +296,7 @@ int alpha_scandir(const char *dir, struct dirent ***namelist,
     return(-1);
 
   qsort((void *)(*namelist), (size_t)i, sizeof(struct dirent *), sort_by_name);
-    
+
   return(i);
 }
 
