@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2006  Andreas Rver
+ * Copyright (C) 2000-2012  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -168,9 +168,6 @@
 
 #define PASSWORD_CHARS "abcdefghijklmnopqrstuvwxyz0123456789"
 
-/* the data directory, made dynamic for more flexability */
-extern char *datadir;
-
 void dcl_setdebuglevel(int level);
 void debugprintf(int lvl, const char *fmt, ...);
 
@@ -185,12 +182,11 @@ bool dcl_fileexists(const char *n);
 
 /* opens files looking into the right directories */
 FILE *open_data_file(const char *name);
-//FILE *open_global_config_file(const char *name);
 FILE *open_local_config_file(const char *name);
 FILE *create_local_config_file(const char *name);
 FILE *open_local_data_file(const char *name);
 FILE *create_local_data_file(const char *name);
-char *homedir();
+char * homedir();
 
 /* returns the filename that would be opened with open_data_file in
  * f, f is max len characters
@@ -198,6 +194,8 @@ char *homedir();
  */
 bool get_data_file_path(const char * fname, char * f, int len);
 
+/* Is the TT window active? */
+extern bool tt_has_focus;
 
 #define MENU_DCLSPEED 4
 #define DEFAULT_GAME_SPEED 0
@@ -208,8 +206,6 @@ int dcl_update_speed(int spd);
 /* for errorchecking */
 #define assert_msg(cond,text) if (!(cond)) { printf(_("Assertion failure: %s\n"), text); exit(1); }
 
-//#define CONFIGDIR "/etc"
-
 /* a function that returns a alphabetically sorted list of
  files in the given dir filtered dith the function given at
  3rd parameter
