@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2006  Andreas Rver
+ * Copyright (C) 2000-2012  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,10 +30,6 @@
    #include <strings.h>
 #endif // __QNXNTO__
 
-#ifdef XCODE
-   #include "osx.h"
-#endif
-
 #define NUMHISCORES 10
 
 #define SCOREFNAME "toppler.hsc"
@@ -127,7 +123,7 @@ static bool hsc_lock(void) {
 
     setegid(GameGroupID);
     int lockfd;
-    
+
     while ((lockfd = open(HISCOREDIR "/" SCOREFNAME ".lck", O_CREAT | O_RDWR | O_EXCL, S_IRUSR | S_IWUSR)) == -1) {
       dcl_wait();
       scr_swap();
@@ -178,7 +174,7 @@ void hsc_init(void) {
 
   setegid(UserGroupID);
 
-  /* asume we use local highscore table */ 
+  /* asume we use local highscore table */
   globalHighscore = false;
   snprintf(highscoreName, 199, "%s/.toppler/%s", homedir(), SCOREFNAME);
 
@@ -194,7 +190,7 @@ void hsc_init(void) {
   snprintf(fname, 200, HISCOREDIR "/" SCOREFNAME);
 
   setegid(GameGroupID);
-  FILE * f = fopen(fname, "a+");
+  FILE * f = fopen(fname, "r+");
   setegid(UserGroupID);
 
   if (f) {
@@ -278,37 +274,37 @@ Uint8 hsc_enter(Uint32 points, Uint8 tower, char *name) {
   if (hsc_lock()) {
 
     int t = NUMHISCORES;
-      
+
     while ((t > 0) && (points > scores[t-1].points)) {
       if (t < NUMHISCORES)
         scores[t] = scores[t-1];
       t--;
     }
-  
+
     if (t < NUMHISCORES) {
-  
+
       strncpy(scores[t].name, name, SCORENAMELEN);
       scores[t].points = points;
       scores[t].tower = tower;
-  
+
       FILE *f;
-  
+
       if (globalHighscore) {
         if (globalHighscore) setegid(GameGroupID);
         f = fopen(highscoreName, "r+b");
         if (globalHighscore) setegid(UserGroupID);
       } else {
-  
+
         /* local highscore: this one might require creating the file */
         fclose(fopen(highscoreName, "a+"));
         f = fopen(highscoreName, "r+b");
       }
-  
+
       savescores(f);
       fclose(f);
 
       hsc_unlock();
-  
+
       return t;
     }
 
