@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2006  Andreas Rver
+ * Copyright (C) 2000-2012  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,17 +38,6 @@
 #include <dirent.h>
 #endif
 
-
-#ifdef XCODE
-#include "toppler_osx.h"
-/* for OS X Application bundles we read it out of the bundle */
-char *datadir=NULL;
-char *localedir=NULL;
-#else
-char *datadir=TOP_DATADIR;
-char *localedir=LOCALEDIR;
-#endif
-
 static void printhelp(void) {
   printf(_("\n\tOptions:\n\n  -f\tEnable fullscreen mode\n  -s\tSilence, disable all sound\n  -dX\tSet debug level to X  (default: %i)\n"), config.debug_level());
 }
@@ -91,34 +80,24 @@ static void QuitFunction(void) {
   SDL_Quit();
 }
 
-
 int main(int argc, char *argv[]) {
-  
-  // The following line was moved from a global variable to a pointer. 
+
+  // The following line was moved from a global variable to a pointer.
   // This was to allow the Mac OS X version of SDL to reposition the current
   // working directory so that the hardcoded paths in the binary to point
   // to the right spot without a lot of jiggery pokery.
   // - jasonk@toast442.org
 
   dataarchive = new archive(open_data_file("toppler.dat"));
-  if(!dataarchive) {
-    perror("Can't open data archive");
-    exit(1);
-  }
 
 #if ENABLE_NLS == 1
   setlocale(LC_MESSAGES, "");
   setlocale(LC_CTYPE, "");
 
   DIR *dir = opendir("locale");
-  if(dir) {
-            
-  bindtextdomain("toppler", dir == NULL ? localedir : "locale");
+  bindtextdomain("toppler", dir == NULL ? LOCALEDIR : "locale");
   closedir(dir);
-  bind_textdomain_codeset("toppler", "UTF-8");
   textdomain("toppler");
-  } 
-    // TODO:  Put in warning if locale won't open.  Set up an error API
 #endif
 
   printf(_("Nebulous version %s"), VERSION);
@@ -131,6 +110,7 @@ int main(int argc, char *argv[]) {
     SDL_WM_SetCaption(_("Nebulous"), NULL);
 
     int mouse = SDL_ShowCursor(config.fullscreen() ? 0 : 1);
+    tt_has_focus = true;
     atexit(QuitFunction);
     srand(time(0));
     startgame();
@@ -138,6 +118,6 @@ int main(int argc, char *argv[]) {
     SDL_ShowCursor(mouse);
     SDL_Quit();
   }
-  
+
   return 0;
 }
