@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2006  Andreas Rver
+ * Copyright (C) 2000-2012  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,7 +24,7 @@
 #include "sprites.h"
 #include "archi.h"
 #include "screen.h"
-#include "event.h"
+#include "keyb.h"
 #include "decl.h"
 #include "level.h"
 #include "sound.h"
@@ -42,12 +42,6 @@
 #define NUMHISCORES 10
 #define HISCORES_PER_PAGE 5
 
-
-// TODO:  We should remove hardcoded keys, as other languages probably don't
-// use 'y' and 'n' as their yes/no.  
-
-static const char *men_exitmenu(Menusystem *m);
-
 static unsigned short menupicture, titledata;
 static unsigned char currentmission = 0;
 
@@ -70,76 +64,73 @@ static void men_reload_sprites(Uint8 what) {
 }
 
 #ifdef GAME_DEBUG_KEYS
-static char *debug_menu_extralife() {
+static const char *debug_menu_extralife(_menusystem *ms) {
   if (ms) lives_add();
   return _("Extra Life");
 }
 
-static char *debug_menu_extrascore(s) {
+static const char *debug_menu_extrascore(_menusystem *ms) {
   if (ms) pts_add(200);
   return _("+200 Points");
 }
 #endif /* GAME_DEBUG_KEYS */
 
 static const char *
-men_main_background_proc(Menusystem *m)
+men_main_background_proc(_menusystem *ms)
 {
-  scr_blit(restsprites.data(menupicture), 0, 0);
-  scr_blit(fontsprites.data(titledata), (SCREENWID - fontsprites.data(titledata)->w) / 2, 20);
-  return NULL;
+  if (ms) {
+    scr_blit(restsprites.data(menupicture), 0, 0);
+    scr_blit(fontsprites.data(titledata), (SCREENWID - fontsprites.data(titledata)->w) / 2, 20);
+    return NULL;
+  }
+  return "";
 }
 
-static const char *redefine(Menusystem *parent,const char *label,event_t event); 
-
-static const char *redefine_menu_up(Menusystem *parent) {
-  return(redefine(parent,_("Up"),up_ev));
-}
-
-static const char *redefine_menu_down(Menusystem *parent) {
-  return(redefine(parent,_("Down"),down_ev));
-}
-
-static const char *redefine_menu_left(Menusystem *parent) {
-  return(redefine(parent,_("Left"),left_ev));
-}
-
-static const char *redefine_menu_right(Menusystem *parent) {
-  return(redefine(parent,_("Right"),right_ev));
-}
-
-static const char *redefine_menu_fire(Menusystem *parent) {
-  return(redefine(parent,_("Fire"),fire_ev));
-}
-
-static const char *redefine(Menusystem *parent,const char *label,event_t event) {
-  static bool in_opt=false;
-  static int blink_cnt=0;
-  std::string s=label;
-  s+=": ";
-  if(parent&&(!in_opt)) {
-    in_opt=true;
-    parent->capture();
-    parent->clear_last_event();
-  } else if(parent&&in_opt) {
-    blink_cnt++;
-    if(parent->get_last_event()&&(parent->get_last_event()->get_keysym()!=SDLK_UNKNOWN)) {
-      events.set_keydef(event,parent->get_last_event()->get_keysym());
-      parent->release();
-      in_opt=false;
-      blink_cnt=0;
+#define REDEFINEREC 5
+static int times_called = 0;
+static const char *redefine_menu_up(_menusystem *ms) {
+  static char buf[50];
+  const char *code[REDEFINEREC] = {_("Up"), _("Down"), _("Left"), _("Right"), _("Fire")};
+  const char *keystr;
+  static int blink, times_called;
+  const ttkey key[REDEFINEREC] = {up_key, down_key, left_key, right_key, fire_key};
+  const char *redef_fmt = "%s:  %s";
+  buf[0] = '\0';
+  if (ms) {
+    switch (ms->mstate) {
+    default:
+      if (key_sdlkey2conv(ms->key, false) == fire_key) {
+        ms->mstate = 1;
+        ms->opt_steal_control = ms->hilited;
+        ms->key = SDLK_UNKNOWN;
+      }
+      break;
+    case 1:
+      if (ms->key != SDLK_UNKNOWN) {
+        key_redefine(key[ms->hilited % REDEFINEREC], ms->key);
+        ms->mstate = 2;
+        ms->opt_steal_control = ms->hilited;
+        blink = 0;
+      } else blink++;
+      break;
+    case 2:
+      ms->mstate = 0;
+      ms->opt_steal_control = -1;
+      break;
     }
+    if ((blink & 4) || (ms->mstate != 1))
+      keystr = SDL_GetKeyName(key_conv2sdlkey(key[ms->hilited % REDEFINEREC], true));
+    else keystr = "";
+    snprintf(buf, 50, redef_fmt, code[ms->hilited % REDEFINEREC], keystr);
+  } else {
+    keystr = SDL_GetKeyName(key_conv2sdlkey(key[times_called], true));
+    snprintf(buf, 50, redef_fmt, code[times_called], keystr);
+    times_called = (times_called + 1) % REDEFINEREC;
   }
-  if(!in_opt || (blink_cnt & 4)) {
-    s+=events.get_keydef(event);
-  }
-  return(s.c_str());
+  return buf;
 }
 
-
-
-
-
-static const char *game_options_menu_password(Menusystem *prevmenu) {
+static const char *game_options_menu_password(_menusystem *prevmenu) {
   static char buf[50];
   char pwd[PASSWORD_LEN+1];
 
@@ -155,59 +146,59 @@ static const char *game_options_menu_password(Menusystem *prevmenu) {
   return buf;
 }
 
-static const char *game_options_menu_statustop(Menusystem *prevmenu) {
+static const char *game_options_menu_statustop(_menusystem *prevmenu) {
   static char txt[30];
   if (prevmenu) {
     config.status_top(!config.status_top());
   }
-  if (config.status_top()) snprintf(txt, sizeof(txt), "%s %c", _("Status on top"), 4);
-  else snprintf(txt, sizeof(txt),"%s %c", _("Status on top"), 3);
+  if (config.status_top()) sprintf(txt, "%s %c", _("Status on top"), 4);
+  else sprintf(txt, "%s %c", _("Status on top"), 3);
 
   return txt;
 }
 
-static const char *game_options_menu_lives(Menusystem *prevmenu) {
+static const char *game_options_menu_lives(_menusystem *prevmenu) {
   static char buf[50];
   int i;
   if (prevmenu) {
-    switch(prevmenu->get_last_event()->get_type()) {
-      case right_ev:
-	config.start_lives(config.start_lives() + 1);
-	if (config.start_lives() > 3) config.start_lives(3);
-	break;
-      case left_ev:
-	config.start_lives(config.start_lives() - 1);
-	if (config.start_lives() < 1) config.start_lives(1);
-	break;
-      default: return NULL;
+    switch (key_sdlkey2conv(prevmenu->key, false)) {
+    case right_key:
+      config.start_lives(config.start_lives() + 1);
+      if (config.start_lives() > 3) config.start_lives(3);
+      break;
+    case left_key:
+      config.start_lives(config.start_lives() - 1);
+      if (config.start_lives() < 1) config.start_lives(1);
+      break;
+    default: return NULL;
     }
   }
-  snprintf(buf, sizeof(buf)-config.start_lives(),_("Lives: "));
+  sprintf(buf, _("Lives: "));
   for (i = 0; i < config.start_lives(); i++)
     sprintf(buf + strlen(buf), "%c", fonttoppler);
   return buf;
 }
 
 static const char *
-game_options_menu_speed(Menusystem *prevmenu)
+game_options_menu_speed(_menusystem *prevmenu)
 {
   // Changing game_speed during a game has no effect until a
   // a new game is started.
   static char buf[50];
   if (prevmenu) {
-    switch(prevmenu->get_last_event()->get_type()) {
-      case right_ev:
-	config.game_speed(config.game_speed() + 1);
-	if (config.game_speed() > MAX_GAME_SPEED) config.game_speed(MAX_GAME_SPEED);
-	break;
-      case left_ev:
-	config.game_speed(config.game_speed() - 1);
-	if (config.game_speed() < 0) config.game_speed(0);
-	break;
-      case fire_ev:
-	config.game_speed((config.game_speed() + 1) % (MAX_GAME_SPEED+1));
-	break;
-      default: return NULL;
+    switch (key_sdlkey2conv(prevmenu->key, false)) {
+    case right_key:
+      config.game_speed(config.game_speed() + 1);
+      if (config.game_speed() > MAX_GAME_SPEED) config.game_speed(MAX_GAME_SPEED);
+      break;
+    case left_key:
+      config.game_speed(config.game_speed() - 1);
+      if (config.game_speed() < 0) config.game_speed(0);
+      break;
+    case fire_key:
+      config.game_speed((config.game_speed() + 1) % (MAX_GAME_SPEED+1));
+      break;
+    default: return NULL;
     }
   }
   snprintf(buf, 50, _("Game Speed: %i"), config.game_speed());
@@ -215,57 +206,64 @@ game_options_menu_speed(Menusystem *prevmenu)
 }
 
 static const char *
-game_options_bonus(Menusystem *ms)
+game_options_bonus(_menusystem *ms)
 {
   static char txt[30];
   if (ms) {
     config.nobonus(!config.nobonus());
   }
-  if (config.nobonus()) snprintf(txt, sizeof(txt),"%s %c", _("Bonus"), 3);
-  else snprintf(txt, sizeof(txt),"%s %c", _("Bonus"), 4);
+  if (config.nobonus()) sprintf(txt, "%s %c", _("Bonus"), 3);
+  else sprintf(txt, "%s %c", _("Bonus"), 4);
 
   return txt;
 }
 
 
-static const char *men_game_options_menu(Menusystem *prevmenu) {
+static const char *men_game_options_menu(_menusystem *prevmenu) {
   static const char * s = _("Game Options");
   if (prevmenu) {
-    Menusystem ms(s, NULL, 0, fontsprites.data(titledata)->h+30);
-    ms.add_option(NULL,game_options_menu_password, SDLK_p, MOF_LEFT);
-    ms.add_option(NULL, game_options_menu_lives, SDLK_l,
-                         (menuoptflags)((int)MOF_PASSKEYS|(int)MOF_LEFT));
-    ms.add_option(NULL, game_options_menu_statustop,SDLK_s);
-    ms.add_option(NULL, game_options_menu_speed, SDLK_g,
-                         (menuoptflags)((int)MOF_PASSKEYS|(int)MOF_LEFT));
-    ms.add_option(NULL, game_options_bonus,SDLK_b);
-    ms.add_spacer();
-    ms.add_option(_("Back"), men_exitmenu);
+    _menusystem *ms = new_menu_system(s, NULL, 0, fontsprites.data(titledata)->h+30);
 
-    ms.run(prevmenu);
+    ms = add_menu_option(ms, NULL, game_options_menu_password, SDLK_UNKNOWN, MOF_LEFT);
+    ms = add_menu_option(ms, NULL, game_options_menu_lives, SDLK_UNKNOWN,
+                         (menuoptflags)((int)MOF_PASSKEYS|(int)MOF_LEFT));
+    ms = add_menu_option(ms, NULL, game_options_menu_statustop);
+    ms = add_menu_option(ms, NULL, game_options_menu_speed, SDLK_UNKNOWN,
+                         (menuoptflags)((int)MOF_PASSKEYS|(int)MOF_LEFT));
+    ms = add_menu_option(ms, NULL, game_options_bonus);
+
+    ms = add_menu_option(ms, NULL, NULL);
+    ms = add_menu_option(ms, _("Back"), NULL);
+
+    ms = run_menu_system(ms, prevmenu);
+
+    free_menu_system(ms);
   }
   return s;
 }
 
-static const char *run_redefine_menu(Menusystem *prevmenu) {
+static const char *run_redefine_menu(_menusystem *prevmenu) {
   if (prevmenu) {
-    Menusystem ms(_("Redefine Keys"), NULL, 0, fontsprites.data(titledata)->h+30);
+    _menusystem *ms = new_menu_system(_("Redefine Keys"), NULL, 0, fontsprites.data(titledata)->h+30);
 
-    ms.add_option(NULL,redefine_menu_up,SDLK_UNKNOWN, MOF_LEFT);
-    ms.add_option(NULL, redefine_menu_down, SDLK_UNKNOWN, MOF_LEFT);
-    ms.add_option(NULL, redefine_menu_left, SDLK_UNKNOWN, MOF_LEFT);
-    ms.add_option(NULL, redefine_menu_right, SDLK_UNKNOWN, MOF_LEFT);
-    ms.add_option(NULL, redefine_menu_fire, SDLK_UNKNOWN, MOF_LEFT);
-    ms.add_option(_("Back"), men_exitmenu);
+    times_called = 0;
 
-    ms.run(prevmenu);
+    ms = add_menu_option(ms, NULL, redefine_menu_up, SDLK_UNKNOWN, MOF_LEFT);
+    ms = add_menu_option(ms, NULL, redefine_menu_up, SDLK_UNKNOWN, MOF_LEFT);
+    ms = add_menu_option(ms, NULL, redefine_menu_up, SDLK_UNKNOWN, MOF_LEFT);
+    ms = add_menu_option(ms, NULL, redefine_menu_up, SDLK_UNKNOWN, MOF_LEFT);
+    ms = add_menu_option(ms, NULL, redefine_menu_up, SDLK_UNKNOWN, MOF_LEFT);
+    ms = add_menu_option(ms, _("Back"), NULL);
 
+    ms = run_menu_system(ms, prevmenu);
+
+    free_menu_system(ms);
   }
   return _("Redefine Keys");
 }
 
 static const char *
-men_options_windowed(Menusystem *ms)
+men_options_windowed(_menusystem *ms)
 {
   static char txt[30];
   if (ms) {
@@ -273,14 +271,14 @@ men_options_windowed(Menusystem *ms)
     scr_reinit();
     SDL_ShowCursor(config.fullscreen() ? 0 : 1);
   }
-  if (config.fullscreen()) snprintf(txt, sizeof(txt),"%s %c", _("Fullscreen"), 4);
-  else snprintf(txt, sizeof(txt),"%s %c", _("Fullscreen"), 3);
+  if (config.fullscreen()) sprintf(txt, "%s %c", _("Fullscreen"), 4);
+  else sprintf(txt, "%s %c", _("Fullscreen"), 3);
 
   return txt;
 }
 
 static const char *
-men_options_sounds(Menusystem *ms)
+men_options_sounds(_menusystem *ms)
 {
   static char txt[30];
   if (ms) {
@@ -296,14 +294,14 @@ men_options_sounds(Menusystem *ms)
       config.nosound(true);
     }
   }
-  if (config.nosound()) snprintf(txt, sizeof(txt),"%s %c", _("Sounds"), 3);
-  else snprintf(txt, sizeof(txt),"%s %c", _("Sounds"), 4);
+  if (config.nosound()) sprintf(txt, "%s %c", _("Sounds"), 3);
+  else sprintf(txt, "%s %c", _("Sounds"), 4);
 
   return txt;
 }
 
   static const char *
-men_options_music(Menusystem *ms)
+men_options_music(_menusystem *ms)
 {
   static char txt[30];
   if (ms) {
@@ -315,8 +313,8 @@ men_options_music(Menusystem *ms)
       config.nomusic(true);
     }
   }
-  if (config.nomusic()) snprintf(txt, sizeof(txt),"%s %c", _("Music"), 3);
-  else snprintf(txt, sizeof(txt),"%s %c", _("Music"), 4);
+  if (config.nomusic()) sprintf(txt, "%s %c", _("Music"), 3);
+  else sprintf(txt, "%s %c", _("Music"), 4);
 
   return txt;
 }
@@ -343,89 +341,89 @@ reload_layer_graphics(void) {
 }
 
 static const char *
-men_alpha_font(Menusystem *ms)
+men_alpha_font(_menusystem *ms)
 {
   static char txt[30];
   if (ms) {
     config.use_alpha_font(!config.use_alpha_font());
     reload_font_graphics();
   }
-  if (config.use_alpha_font()) snprintf(txt, sizeof(txt),"%s %c", _("Font alpha"), 4);
-  else snprintf(txt, sizeof(txt),"%s %c", _("Font alpha"), 3);
+  if (config.use_alpha_font()) sprintf(txt, "%s %c", _("Font alpha"), 4);
+  else sprintf(txt, "%s %c", _("Font alpha"), 3);
 
   return txt;
 }
 
 static const char *
-men_alpha_sprites(Menusystem *ms)
+men_alpha_sprites(_menusystem *ms)
 {
   static char txt[30];
   if (ms) {
     config.use_alpha_sprites(!config.use_alpha_sprites());
     reload_robot_graphics();
   }
-  if (config.use_alpha_sprites()) snprintf(txt, sizeof(txt),"%s %c", _("Sprites alpha"), 4);
-  else snprintf(txt, sizeof(txt),"%s %c", _("Sprites alpha"), 3);
+  if (config.use_alpha_sprites()) sprintf(txt, "%s %c", _("Sprites alpha"), 4);
+  else sprintf(txt, "%s %c", _("Sprites alpha"), 3);
 
   return txt;
 }
 
 static const char *
-men_alpha_layer(Menusystem *ms)
+men_alpha_layer(_menusystem *ms)
 {
   static char txt[30];
   if (ms) {
     config.use_alpha_layers(!config.use_alpha_layers());
     reload_layer_graphics();
   }
-  if (config.use_alpha_layers()) snprintf(txt, sizeof(txt),"%s %c", _("Scroller alpha"), 4);
-  else snprintf(txt, sizeof(txt),"%s %c", _("Scroller alpha"), 3);
+  if (config.use_alpha_layers()) sprintf(txt, "%s %c", _("Scroller alpha"), 4);
+  else sprintf(txt, "%s %c", _("Scroller alpha"), 3);
 
   return txt;
 }
 
 static const char *
-men_alpha_menu(Menusystem *ms)
+men_alpha_menu(_menusystem *ms)
 {
   static char txt[30];
   if (ms) {
     config.use_alpha_darkening(!config.use_alpha_darkening());
   }
-  if (config.use_alpha_darkening()) snprintf(txt, sizeof(txt),"%s %c", _("Shadowing"), 4);
-  else snprintf(txt, sizeof(txt),"%s %c", _("Shadowing"), 3);
+  if (config.use_alpha_darkening()) sprintf(txt, "%s %c", _("Shadowing"), 4);
+  else sprintf(txt, "%s %c", _("Shadowing"), 3);
 
   return txt;
 }
 
 static const char *
-men_waves_menu(Menusystem *ms)
+men_waves_menu(_menusystem *ms)
 {
   if (ms) {
-    switch(ms->get_last_event()->get_type()) {
-      case fire_ev:
-	config.waves_type((config.waves_type() + 1) % configuration::num_waves);
-	break;
-      case right_ev:
-	config.waves_type(config.waves_type() + 1);
-	if (config.waves_type() >= configuration::num_waves) config.waves_type(configuration::num_waves - 1);
-	break;
-      case left_ev:
-	config.waves_type(config.waves_type() - 1);
-	if (config.waves_type() < 0) config.waves_type(0);
-	break;
-      default: return NULL;
-      }
+    switch (key_sdlkey2conv(ms->key, false)) {
+    case fire_key:
+      config.waves_type((config.waves_type() + 1) % configuration::num_waves);
+      break;
+    case right_key:
+      config.waves_type(config.waves_type() + 1);
+      if (config.waves_type() >= configuration::num_waves) config.waves_type(configuration::num_waves - 1);
+      break;
+    case left_key:
+      config.waves_type(config.waves_type() - 1);
+      if (config.waves_type() < 0) config.waves_type(0);
+      break;
+    default: return NULL;
+    }
   }
   switch(config.waves_type()) {
-    case configuration::waves_nonreflecting: return _("Nonreflecting waves");
-    case configuration::waves_simple: return _("Simple waves");
-    case configuration::waves_expensive: return _("Expensive waves");
-    default: return _("Error");
+  case configuration::waves_nonreflecting: return _("Nonreflecting waves");
+  case configuration::waves_simple: return _("Simple waves");
+  case configuration::waves_expensive: return _("Expensive waves");
+  default: return _("Error");
   }
 }
 
 static const char *
-men_full_scroller(Menusystem *ms)
+men_full_scroller(_menusystem *ms)
 {
   if (ms) {
     config.use_full_scroller(!config.use_full_scroller());
@@ -436,61 +434,74 @@ men_full_scroller(Menusystem *ms)
 
 
 static const char *
-men_alpha_options(Menusystem *mainmenu) {
+men_alpha_options(_menusystem *mainmenu) {
   static const char * s = _("Alpha Options");
   if (mainmenu) {
 
-    Menusystem ms(s, NULL, 0, fontsprites.data(titledata)->h+30);
+    _menusystem *ms = new_menu_system(s, NULL, 0, fontsprites.data(titledata)->h+30);
 
-    ms.add_spacer();
-    ms.add_option(NULL, men_alpha_font, SDLK_UNKNOWN, MOF_RIGHT);
-    ms.add_option(NULL, men_alpha_sprites, SDLK_UNKNOWN, MOF_RIGHT);
-    ms.add_option(NULL, men_alpha_layer, SDLK_UNKNOWN, MOF_RIGHT);
-    ms.add_option(NULL, men_alpha_menu, SDLK_UNKNOWN, MOF_RIGHT);
-    ms.add_spacer();
-    ms.add_option(_("Back"), men_exitmenu);
+    if (!ms) return NULL;
 
-    ms.run(mainmenu);
+    ms = add_menu_option(ms, NULL, men_alpha_font, SDLK_UNKNOWN, MOF_RIGHT);
+    ms = add_menu_option(ms, NULL, men_alpha_sprites, SDLK_UNKNOWN, MOF_RIGHT);
+    ms = add_menu_option(ms, NULL, men_alpha_layer, SDLK_UNKNOWN, MOF_RIGHT);
+    ms = add_menu_option(ms, NULL, men_alpha_menu, SDLK_UNKNOWN, MOF_RIGHT);
+
+    ms = add_menu_option(ms, NULL, NULL);
+    ms = add_menu_option(ms, _("Back"), NULL);
+
+    ms = run_menu_system(ms, mainmenu);
+
+    free_menu_system(ms);
   }
   return s;
 }
 
 static const char *
-men_options_graphic(Menusystem *mainmenu) {
+men_options_graphic(_menusystem *mainmenu) {
   static const char *s = _("Graphics");
   if (mainmenu) {
 
-    Menusystem ms(s, NULL, 0, fontsprites.data(titledata)->h+30);
+    _menusystem *ms = new_menu_system(s, NULL, 0, fontsprites.data(titledata)->h+30);
 
-    ms.add_option(NULL, men_options_windowed,SDLK_f);
-    ms.add_option(NULL, men_alpha_options,SDLK_a);
-    ms.add_option(NULL, men_waves_menu, SDLK_w, MOF_PASSKEYS);
-    ms.add_option(NULL, men_full_scroller, SDLK_s);
-    ms.add_spacer();
-    ms.add_option(_("Back"), men_exitmenu);
+    if (!ms) return NULL;
 
-    ms.run(mainmenu);
+    ms = add_menu_option(ms, NULL, men_options_windowed);
+    ms = add_menu_option(ms, NULL, men_alpha_options);
+    ms = add_menu_option(ms, NULL, men_waves_menu, SDLK_UNKNOWN, MOF_PASSKEYS);
+    ms = add_menu_option(ms, NULL, men_full_scroller, SDLK_UNKNOWN);
 
+    ms = add_menu_option(ms, NULL, NULL);
+    ms = add_menu_option(ms, _("Back"), NULL);
+
+    ms = run_menu_system(ms, mainmenu);
+
+    free_menu_system(ms);
   }
   return s;
 }
 
 static const char *
-men_options(Menusystem *mainmenu) {
+men_options(_menusystem *mainmenu) {
   static const char * s = _("Options");
   if (mainmenu) {
 
-    Menusystem ms(s, NULL, 0, fontsprites.data(titledata)->h+30);
+    _menusystem *ms = new_menu_system(s, NULL, 0, fontsprites.data(titledata)->h+30);
 
-    ms.add_option(NULL, men_game_options_menu, SDLK_o);
-    ms.add_option(NULL, run_redefine_menu, SDLK_r);
-    ms.add_option(NULL, men_options_graphic, SDLK_g );
-    ms.add_option(NULL, men_options_sounds, SDLK_s);
-    ms.add_option(NULL, men_options_music,SDLK_m);
-    ms.add_spacer();
-    ms.add_option(_("Back"), men_exitmenu);
+    if (!ms) return NULL;
 
-    ms.run(mainmenu); 
+    ms = add_menu_option(ms, NULL, men_game_options_menu);
+    ms = add_menu_option(ms, NULL, run_redefine_menu);
+    ms = add_menu_option(ms, NULL, men_options_graphic);
+    ms = add_menu_option(ms, NULL, men_options_sounds);
+    ms = add_menu_option(ms, NULL, men_options_music);
+
+    ms = add_menu_option(ms, NULL, NULL);
+    ms = add_menu_option(ms, _("Back"), NULL);
+
+    ms = run_menu_system(ms, mainmenu);
+
+    free_menu_system(ms);
   }
   return s;
 }
@@ -549,17 +560,13 @@ calc_hiscores_maxlen(int *max_pos, int * max_points, int *max_name)
 }
 
 static const char *
-men_hiscores_background_proc(Menusystem *ms)
+men_hiscores_background_proc(_menusystem *ms)
 {
   static int blink_r = 120, blink_g = 200, blink_b = 40;
   static int next_page = 0;
 
   if (ms) {
 
-    if(ms->get_last_event()) {
-      ms->set_exit();
-    }
-
     scr_blit(restsprites.data(menupicture), 0, 0);
     scr_blit(fontsprites.data(titledata), (SCREENWID - fontsprites.data(titledata)->w) / 2, 20);
 
@@ -625,8 +632,10 @@ men_hiscores_background_proc(Menusystem *ms)
 
 static void show_scores(bool back = true, int mark = -1) {
   static char buf[50];
-  snprintf(buf, 50, _("Scores for %s"), _(lev_missionname(currentmission)));
-  Menusystem ms(buf, men_hiscores_background_proc, 0, fontsprites.data(titledata)->h + 30);
+  snprintf(buf, 50, _("Scores for %s"), lev_missionname(currentmission));
+  _menusystem *ms = new_menu_system(buf, men_hiscores_background_proc, 0, fontsprites.data(titledata)->h + 30);
+
+  if (!ms) return;
 
   hsc_select(lev_missionname(currentmission));
 
@@ -642,14 +651,16 @@ static void show_scores(bool back = true, int mark = -1) {
   hiscores_hilited = mark;
 
   /* fake options; the empty lines are used by the background proc */
-  for (int tmpz = 0; tmpz < HISCORES_PER_PAGE; tmpz++) ms.add_spacer();
+  for (int tmpz = 0; tmpz < HISCORES_PER_PAGE; tmpz++) ms = add_menu_option(ms, NULL, NULL);
 
   if (back)
-    ms.add_option(_("Back"), NULL);
+    ms = add_menu_option(ms, _("Back"), NULL);
   else
-    ms.add_option( _("OK"), NULL);
+    ms = add_menu_option(ms, _("OK"), NULL);
 
-  ms.run();
+  ms = run_menu_system(ms, 0);
+
+  free_menu_system(ms);
 }
 
 static void
@@ -713,7 +724,7 @@ static void men_highscore(unsigned long pt, int twr) {
    */
   if (hsc_canEnter(pt)) {
 
-    Menusystem::set_bgproc(congrats_background_proc);
+    set_men_bgproc(congrats_background_proc);
 
     char name[SCORENAMELEN+1];
 
@@ -759,7 +770,7 @@ main_game_loop()
 
   gam_newgame();
   bns_restart();
-    
+
   do {
     ttsounds::instance()->startsound(SND_WATER);
     do {
@@ -796,7 +807,7 @@ main_game_loop()
 
 #ifdef HUNT_THE_FISH
 static const char *
-men_main_bonusgame_proc()
+men_main_bonusgame_proc(_menusystem *ms)
 {
   if (ms) {
     gam_newgame();
@@ -809,54 +820,49 @@ men_main_bonusgame_proc()
 #endif /* HUNT_THE_FISH */
 
 static const char *
-men_main_startgame_proc(Menusystem *ms)
+men_main_startgame_proc(_menusystem *ms)
 {
   if (ms) {
     int missioncount = lev_missionnumber();
-    switch(ms->get_last_event()->get_type()) {
-      case fire_ev: 
-	dcl_update_speed(config.game_speed());
-	snd_musicVolume(MIX_MAX_VOLUME/4);
-	main_game_loop();
-	snd_musicVolume(MIX_MAX_VOLUME);
-	dcl_update_speed(MENU_DCLSPEED);
-	break;
-      case right_ev: currentmission = (currentmission + 1) % missioncount; 
-	break;
-      case left_ev: currentmission = (currentmission + missioncount - 1) % missioncount; 
-        break;
-      default:
-	return NULL;  
-    }  
+    switch (key_sdlkey2conv(ms->key, false)) {
+    case fire_key:
+      dcl_update_speed(config.game_speed());
+      snd_musicVolume(MIX_MAX_VOLUME/4);
+      main_game_loop();
+      snd_musicVolume(MIX_MAX_VOLUME);
+      dcl_update_speed(MENU_DCLSPEED);
+      break;
+    case right_key: currentmission = (currentmission + 1) % missioncount; break;
+    case left_key: currentmission = (currentmission + missioncount - 1) % missioncount; break;
+    default: return NULL;
+    }
   }
   static char s[30];
   snprintf(s, 30, _("%c Start: %s %c"), fontptrleft, _(lev_missionname(currentmission)), fontptrright);
-  return s; 
+  return s;
 }
 
 static const char *
-men_main_highscore_proc(Menusystem *ms)
+men_main_highscore_proc(_menusystem *ms)
 {
   if (ms) {
-   show_scores();
+    show_scores();
   }
   return _("Highscores");
 }
 
 static const char *
-men_main_leveleditor_proc(Menusystem *ms)
+men_main_leveleditor_proc(_menusystem *ms)
 {
   if (ms) {
-    //snd_stoptitle();
     le_edit();
-    //(void)get_nextkey();
-    //snd_playtitle();
+    (void)key_sdlkey();
   }
   return _("Level Editor");
 }
 
 static const char *
-men_main_timer_proc(Menusystem *ms)
+men_main_timer_proc(_menusystem *ms)
 {
   if (ms) {
     Uint8 num_demos = 0;
@@ -875,7 +881,7 @@ men_main_timer_proc(Menusystem *ms)
       if (lev_loadmission(tmiss)) {
         num_towers = lev_towercount();
 
-        for (Uint8 idx = 0; (idx < num_towers) && (num_demos < 255); idx++) {
+        for (Uint8 idx = 0; (idx < num_towers) && (num_demos < 256); idx++) {
           lev_selecttower(idx);
           lev_get_towerdemo(demolen, demobuf);
           if (demolen) demos[num_demos++] = idx;
@@ -901,29 +907,22 @@ men_main_timer_proc(Menusystem *ms)
   return NULL;
 }
 
-static const char *men_exitmenu(Menusystem *m) {
-  if(m) {
-    m->set_exit();
-  }
-  return(0);
-}
-
 static const char *
-men_game_return2game(Menusystem *tms)
+men_game_return2game(_menusystem *tms)
 {
   if (tms) {
-    tms->set_exit();
-    tms->set_state(0);
+    tms->exitmenu = true;
+    tms->mstate = 0;
   }
   return _("Return to Game");
 }
 
 static const char *
-men_game_leavegame(Menusystem *tms)
+men_game_leavegame(_menusystem *tms)
 {
   if (tms) {
-    tms->set_exit();
-    tms->set_state(1);
+    tms->exitmenu = true;
+    tms->mstate = 1;
   }
   return _("Quit Game");
 }
@@ -932,14 +931,16 @@ men_game_leavegame(Menusystem *tms)
 
 #ifdef GAME_DEBUG_KEYS
 void run_debug_menu(void) {
-  Menusystem ms(_("DEBUG MENU"), NULL, 0, SCREENHEI / 5);
+  _menusystem *ms = new_menu_system(_("DEBUG MENU"), NULL, 0, SCREENHEI / 5);
 
-  ms.add_option(NULL, debug_menu_extralife);
-  ms.add_option(NULL, debug_menu_extrascore);
-  ms.add_option(NULL, NULL);
-  ms.add_option(_("Back to Game"), men_exitmenu);
+  ms = add_menu_option(ms, NULL, debug_menu_extralife);
+  ms = add_menu_option(ms, NULL, debug_menu_extrascore);
+  ms = add_menu_option(ms, NULL, NULL);
+  ms = add_menu_option(ms, _("Back to Game"), NULL);
 
-  ms.run(); 
+  ms = run_menu_system(ms, 0);
+
+  free_menu_system(ms);
 }
 #endif
 
@@ -948,87 +949,59 @@ void men_init(void) {
 }
 
 void men_main() {
-  Menusystem ms(NULL,men_main_background_proc,0, fontsprites.data(titledata)->h + 30);
+  _menusystem *ms;
 
-  ms.set_timeproc(200, men_main_timer_proc);
+  ms = new_menu_system(NULL, men_main_background_proc, 0, fontsprites.data(titledata)->h + 30);
 
-  ms.add_option(NULL, men_main_startgame_proc, SDLK_s, MOF_PASSKEYS);
-  ms.add_spacer();
-  ms.add_option(NULL,men_main_highscore_proc,SDLK_h);
-  ms.add_option(NULL,men_options,SDLK_o);
-  ms.add_option(NULL,men_main_leveleditor_proc,SDLK_e);
+  if (!ms) return;
+
+  ms = set_menu_system_timeproc(ms, 200, men_main_timer_proc);
+
+  ms = add_menu_option(ms, NULL, men_main_startgame_proc, SDLK_s, MOF_PASSKEYS);
+  ms = add_menu_option(ms, NULL, NULL);
+  ms = add_menu_option(ms, NULL, men_main_highscore_proc, SDLK_h);
+  ms = add_menu_option(ms, NULL, men_options, SDLK_o);
+  ms = add_menu_option(ms, NULL, men_main_leveleditor_proc, SDLK_e);
 #ifdef HUNT_THE_FISH
-  ms.add_option( NULL, men_main_bonusgame_proc);
+  ms = add_menu_option(ms, NULL, men_main_bonusgame_proc);
 #endif
-  ms.add_spacer();
-  ms.add_option(_("Quit"), men_exitmenu, SDLK_q);
-  
-  ms.run();
+  ms = add_menu_option(ms, NULL, NULL);
+  ms = add_menu_option(ms, _("Quit"), NULL, SDLK_q);
+
+  ms->wraparound = true;
+
+  ms = run_menu_system(ms, 0);
+
+  free_menu_system(ms);
 }
 
 bool men_game() {
-  Menusystem ms(_("Game Options"),NULL, 0, fontsprites.data(titledata)->h+30);
+  _menusystem *ms;
+  bool do_quit;
   int  speed = dcl_update_speed(MENU_DCLSPEED);
 
-  ms.add_spacer();
-  ms.add_option(NULL,men_game_return2game,SDLK_r);
-  ms.add_option(NULL,men_options,SDLK_o);
-  ms.add_spacer();
-  ms.add_option(NULL, men_game_leavegame,SDLK_q);
+  ms = new_menu_system(NULL, NULL, 0, fontsprites.data(titledata)->h + 30);
 
-  ms.set_wraparound(true);
-  ms.run();
+  if (!ms) return 0;
+
+  ms = add_menu_option(ms, NULL, men_game_return2game);
+  ms = add_menu_option(ms, NULL, men_options, SDLK_o);
+  ms = add_menu_option(ms, NULL, NULL);
+  ms = add_menu_option(ms, NULL, men_game_leavegame);
+
+  ms->wraparound = true;
+
+  ms = run_menu_system(ms, 0);
+
+  do_quit = ms->mstate != 0;
+
+  free_menu_system(ms);
 
   dcl_update_speed(speed);
-  return(ms.get_state() != 0);
+
+  return do_quit;
 }
 
-static const char *men_yn_option_yes(Menusystem *ms)
-{
-  if (ms) {
-    ms->set_state(1);
-    ms->set_exit();
-  } 
-  return _("Yes");
+void men_done(void) {
 }
 
-static const char * men_yn_option_no(Menusystem *ms)
-{
-  if (ms) {
-    ms->set_state(0);
-    ms->set_exit();
-  } 
-  return _("No");
-}
-
-
-unsigned char men_yn(char* s, bool defchoice, menuopt_callback_proc pr) {
-  Menusystem ms(s, pr, 0, SCREENHEI / 5);
-  ms.add_option(NULL,men_yn_option_no,SDLK_n);
-  ms.add_option(NULL,men_yn_option_yes,SDLK_y);
-  ms.set_state(defchoice ? 1 : 0);
-  ms.run();
-  return(ms.get_state());
-}
-
-void men_info(const char* s, long timeout, int fire) {
-    bool ende=false;
-  do {
-    Menusystem::call_bgproc();
-    scr_writetext_center((SCREENHEI / 5), s);
-    if (fire)
-      scr_writetext_center((SCREENHEI / 5) + 2 * FONTHEI, (fire == 1) ? _("Press fire") : _("Press space"));
-    scr_swap();
-    dcl_wait();
-    Event *e=events.get_input();
-    if (timeout > 0) timeout--;
-    if (!timeout) ende = true;
-    if(e) {
-	if ((fire == 2) && (e->get_keysym() == SDLK_SPACE)) ende = true;
-	else if ((fire != 2) && e->get_type()==fire_ev) ende = true;
-	delete(e); 
-    }
-  } while (!ende); 
-}
-
-
