@@ -1,5 +1,5 @@
 /* Tower Toppler - Nebulus
- * Copyright (C) 2000-2006  Andreas Rver
+ * Copyright (C) 2000-2012  Andreas Rver
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
 
 #include "txtsys.h"
 #include "screen.h"
-#include "event.h"
+#include "keyb.h"
 #include "menu.h"
 #include <stdlib.h>
 #include <string.h>
@@ -84,60 +84,61 @@ void textsystem::addline(char *line)
 void textsystem::run()
 {
   bool ende = false;
+  SDLKey key = SDLK_UNKNOWN;
 
   do {
+    (void)key_readkey();
+
     draw();
 
-    Event *e=events.get_input();
-    if(e) {
-      switch (e->get_type()) {
-	case up_ev:
-	if (yoffs >= FONTHEI) yoffs -= FONTHEI;
-	else yoffs = 0;
-	break;
-      case down_ev:
-	if (yoffs + (shownlines*FONTHEI) < (numlines*FONTHEI)) yoffs += FONTHEI;
-	else yoffs = (numlines - shownlines+1)*FONTHEI;
-	break;
-      case break_ev:
-	ende = true;
-	break;
-      case left_ev:
-	if (xoffs >= FONTWID) xoffs -= FONTWID;
-	else xoffs = 0;
-	break;
-      case right_ev:
-	if (xoffs <= max_length-SCREENWID-FONTWID) xoffs += FONTWID;
-	else xoffs = max_length-SCREENWID;
-	break;
-      case key_ev:
-	switch (e->get_keysym()) {
-	  case SDLK_PAGEUP:
-	    if (yoffs >= shownlines*FONTHEI) yoffs -= shownlines*FONTHEI;
-	    else yoffs = 0;
-	    break;
-	  case SDLK_SPACE:
-	  case SDLK_PAGEDOWN:
-	    if ((yoffs/FONTHEI) + (shownlines*2) <= numlines)
-	      yoffs += shownlines*FONTHEI;
-	    else yoffs = (numlines - shownlines+1)*FONTHEI;
-	    break;
-	  case SDLK_HOME:
-	    yoffs = 0;
-	    break;
-	  case SDLK_END:
-	    yoffs = (numlines - shownlines+1)*FONTHEI;
-	    break;
-	  case SDLK_RETURN:
-	  case SDLK_ESCAPE:
-	    ende = true;
-	    break;
-	  default: break;
-	}
-	default: break;
+    key = key_sdlkey();
+
+    switch (key_sdlkey2conv(key, false)) {
+    case up_key:
+      if (yoffs >= FONTHEI) yoffs -= FONTHEI;
+      else yoffs = 0;
+      break;
+    case down_key:
+      if (yoffs + (shownlines*FONTHEI) < (numlines*FONTHEI)) yoffs += FONTHEI;
+      else yoffs = (numlines - shownlines+1)*FONTHEI;
+      break;
+    case break_key:
+      ende = true;
+      break;
+    case left_key:
+      if (xoffs >= FONTWID) xoffs -= FONTWID;
+      else xoffs = 0;
+      break;
+    case right_key:
+      if (xoffs <= max_length-SCREENWID-FONTWID) xoffs += FONTWID;
+      else xoffs = max_length-SCREENWID;
+      break;
+    default:
+      switch (key) {
+      case SDLK_PAGEUP:
+        if (yoffs >= shownlines*FONTHEI) yoffs -= shownlines*FONTHEI;
+        else yoffs = 0;
+        break;
+      case SDLK_SPACE:
+      case SDLK_PAGEDOWN:
+        if ((yoffs/FONTHEI) + (shownlines*2) <= numlines)
+          yoffs += shownlines*FONTHEI;
+        else yoffs = (numlines - shownlines+1)*FONTHEI;
+        break;
+      case SDLK_HOME:
+        yoffs = 0;
+        break;
+      case SDLK_END:
+        yoffs = (numlines - shownlines+1)*FONTHEI;
+        break;
+      case SDLK_RETURN:
+      case SDLK_ESCAPE:
+        ende = true;
+        break;
+      default: break;
       }
-      delete(e);
     }
+
   } while (!ende);
 }
 
